# `BioClients.fda`

## FDA

OpenFDA Adverse Event Reports REST API client.

* <https://api.fda.gov>
* <https://api.fda.gov/drug/event.json?search=patient.drug.openfda.pharm_class_epc:"nonsteroidal+anti-inflammatory+drug"&count=patient.reaction.reactionmeddrapt.exact>
